pub struct Peer {
pub ip: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub port: Option<i64>,
pub principal: Option<String>,
pub region_code: Option<String>,
}Expand description
This message defines attributes for a node that handles a network request. The node can be either a service or an application that sends, forwards, or receives the request. Service peers should fill in principal and labels as appropriate.
This type is not used in any activity, and only used as part of another schema.
Fields
ip: Option<String>The IP address of the peer.
labels: Option<HashMap<String, String>>The labels associated with the peer.
port: Option<i64>The network port of the peer.
principal: Option<String>The identity of this peer. Similar to Request.auth.principal, but relative to the peer instead of the request. For example, the identity associated with a load balancer that forwarded the request.
region_code: Option<String>The CLDR country/region code associated with the above IP address. If the IP address is private, the region_code should reflect the physical location where this peer is running.