pub struct ResourceInfo {
pub container: Option<String>,
pub location: Option<String>,
pub name: Option<String>,
pub permission: Option<String>,
pub type_: Option<String>,
}Expand description
Describes a resource referenced in the request.
This type is not used in any activity, and only used as part of another schema.
Fields
container: Option<String>Optional. The identifier of the container of this resource. For Google Cloud APIs, the resource container must be one of the following formats: - projects/ - folders/ - organizations/ Required for the policy enforcement on the container level (e.g. VPCSC, Location Policy check, Org Policy check).
location: Option<String>Optional. The location of the resource, it must be a valid zone, region or multiregion, for example: “europe-west4”, “northamerica-northeast1-a”. Required for location policy check.
name: Option<String>The name of the resource referenced in the request.
permission: Option<String>The resource permission needed for this request. The format must be “{service}/{plural}.{verb}”.
type_: Option<String>The resource type in the format of “{service}/{kind}”.