pub struct Response {
pub backend_latency: Option<Duration>,
pub code: Option<i64>,
pub headers: Option<HashMap<String, String>>,
pub size: Option<i64>,
pub time: Option<DateTime<Utc>>,
}Expand description
This message defines attributes for a typical network response. It generally models semantics of an HTTP response.
This type is not used in any activity, and only used as part of another schema.
Fields
backend_latency: Option<Duration>The amount of time it takes the backend service to fully respond to a request. Measured from when the destination service starts to send the request to the backend until when the destination service receives the complete response from the backend.
code: Option<i64>The HTTP response status code, such as 200 and 404.
headers: Option<HashMap<String, String>>The HTTP response headers. If multiple headers share the same key, they must be merged according to HTTP spec. All header keys must be lowercased, because HTTP header keys are case-insensitive.
size: Option<i64>The HTTP response size in bytes. If unknown, it must be -1.
time: Option<DateTime<Utc>>The timestamp when the destination service sends the last byte of the response.